# Generated from the Telepathy spec
"""Copyright (C) 2008 Collabora Ltd.
Copyright (C) 2008 Nokia Corporation

    This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
USA.
  
"""

import dbus.service


class ChannelInterfaceMessages(dbus.service.Interface):
    """\
      This interface extends the Text interface to support more general
        messages, including:

      
        messages with attachments (like MIME multipart/mixed)
        groups of alternatives (like MIME multipart/alternative)
        delivery reports
        any extra types of message we need in future
      

      It also provides a hook for improved sent
        message status notification, to be used by the DeliveryReporting
        interface.

      Although this specification supports formatted (rich-text)
        messages with unformatted alternatives, implementations SHOULD NOT
        attempt to send formatted messages until the Telepathy specification
        has also been extended to cover capability discovery for message
        formatting.

      
        We intend to expose all rich-text messages as XHTML-IM, but on some
        protocols, formatting is an extremely limited subset of that format
        (e.g. there are protocols where foreground/background colours, font
        and size can be set, but only for entire messages).
        Until we can tell UIs what controls to offer to the user, it's
        unfriendly to offer the user controls that may have no effect.
      

      If this interface is present, clients that support it SHOULD
        listen for the MessageSent and MessageReceived signals, and
        ignore the Sent and Received signal on the Text interface
        (which are guaranteed to duplicate signals from this interface).
    """

    def __init__(self):
        self._interfaces.add('org.freedesktop.Telepathy.Channel.Interface.Messages.DRAFT')

    @dbus.service.method('org.freedesktop.Telepathy.Channel.Interface.Messages.DRAFT', in_signature='aa{sv}u', out_signature='s')
    def SendMessage(self, Message, Flags):
        """
        Submit a message to the server for sending.
          If this method returns successfully, the message has been submitted
          to the server and the MessageSent signal is emitted. A corresponding
          Sent signal on the Text interface MUST also be emitted.

        If this method fails, message submission to the server has failed
          and no signal on this interface (or the Text interface) is
          emitted.
      
        """
        raise NotImplementedError
  
    @dbus.service.method('org.freedesktop.Telepathy.Channel.Interface.Messages.DRAFT', in_signature='uau', out_signature='a{uv}')
    def GetPendingMessageContent(self, Message_ID, Parts):
        """
        Retrieve the content of one or more parts of a pending message.
        Note that this function may take a considerable amount of time
        to return if the part's 'needs-retrieval' flag is true; consider
        extending the default D-Bus method call timeout. Additional API is
        likely to be added in future, to stream large message parts.
      
        """
        raise NotImplementedError
  
    @dbus.service.signal('org.freedesktop.Telepathy.Channel.Interface.Messages.DRAFT', signature='aa{sv}s')
    def MessageSent(self, Content, Message_Token):
        """
        Signals that a message has been submitted for sending. This
        MUST be emitted exactly once per emission of the Sent signal on the
        Text interface.

        
          This signal allows a process that is not the caller of
          SendMessage to log sent messages. The double signal-emission
          means that clients can safely follow the following rule:
          if the channel has the Messages interface, listen for
          Messages.MessageSent only; otherwise, listen for Text.Sent only.
        
      
        """
        pass
  
    @dbus.service.signal('org.freedesktop.Telepathy.Channel.Interface.Messages.DRAFT', signature='au')
    def PendingMessagesRemoved(self, Message_IDs):
        """
        The messages with the given IDs have been removed from the
        PendingMessages list. Clients SHOULD NOT attempt to acknowledge
        those messages.

        
          This completes change notification for the PendingMessages property
          (previously, there was change notification when pending messages
          were added, but not when they were removed).
        
      
        """
        pass
  
    @dbus.service.signal('org.freedesktop.Telepathy.Channel.Interface.Messages.DRAFT', signature='aa{sv}')
    def MessageReceived(self, Message):
        """
        Signals that a message has been received and added to the pending
        messages queue. This MUST be emitted exactly once per emission of the
        Received signal on the Text interface.

        
          The double signal-emission means that clients can safely follow
          the following rule: if the channel has the Messages interface,
          listen for Messages.MessageReceived only; otherwise, listen for
          Text.Received only.
        
      
        """
        pass
  